#+
# Two different types of sqlite3 tables are maintained
# 'current' file:
#	each table has one row for each monitor, and contains
#   - monitor name
#   - timestamp when the attribute value was seen the first time.
#   _ current value
# 'history' files:
#	there is a single file for each monitor, containing the
#   history for each attribute
#	Records are added only when a parameter changes value.
#   Each table has
#	- timestamp when value was first seen
#   - value of attribute
#-

import os
import sys
import libtiny
from json import loads

def table_layout():

	#tbl = os.path.join( os.path.dirname(__file__), '..')
	#tbl = os.path.join( tbl, 'etc', 'ark-ping-layout.json' )
	tbl = os.path.join(os.sep, 'etc', 'ark-ping-watch', 'ark-ping-layout.json')

	if not os.path.isfile( tbl ):
		sys.stderr.write( "%s does not exist\n"%tbl )
		sys.exit(1)

	tbl = open( tbl ).read()
	tbl = loads(tbl)

	tbl_names = [ str(k) for k in list(tbl.keys()) ]
	tbl_task  = [ k for k in tbl_names if 'task' in tbl[k] and tbl[k]['task'] == 1 ]

	return (tbl, tbl_names, tbl_task)

def validate_attributes( attributes, exit=True ):

	tbl, tbl_names, tbl_task = table_layout()

	n = 0
	for attr in attributes:
		tbl = attr.split('=')[0]
		if tbl not in tbl_names:
			n += 1
			sys.stderr.write( "illegal table=%s\n"%tbl )

	if n > 0:
		if exit:
			sys.stderr.write( "must be one of %s\n"%','.join(sorted(tbl_names)) )
			sys.exit(1)

	return True if n == 0 else False

def expand_attributes( attributes, exit=True ):

	tbl, tbl_names, tbl_task = table_layout()

	n = 0
	full_name = []

	for attr in attributes:

		good = False
		tbl = attr.split('=')[0]

		for tbl_name in tbl_names:
			if tbl_name.startswith(tbl):
				good = True
				full_name.append(tbl_name)

		if not good:
			n += 1
			sys.stderr.write( "no table starts with %s\n"%tbl )

	if n > 0:
		if exit:
			sys.stderr.write( "must be one of %s\n"%','.join(sorted(tbl_names)) )
			sys.exit(1)

	full_name = list ( set(full_name) )

	return full_name
